# Generated by Django 3.1.2 on 2020-10-15 20:02

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0004_remove_profile_current_weight'),
    ]

    operations = [
        migrations.RenameField(
            model_name='profile',
            old_name='daily_cal_in',
            new_name='Daily_Calories',
        ),
    ]
