# Generated by Django 3.1.2 on 2020-10-14 13:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('activityLibrary', '0003_recipe_ingredients'),
    ]

    operations = [
        migrations.AlterField(
            model_name='activity',
            name='icon',
            field=models.ImageField(default='default.jpg', upload_to='activity_thumbnails'),
        ),
    ]
