{% extends "users/base.html" %}
{% block content %}
    <h2>You have been logged out</h2>
    <div class="content-section">
    <div class="border-top pt-3">
        <small class="text-muted">
            <a href={% url 'login' %}>Log In Again</a>
        </small>
    </div>
    </div>
{% endblock content %}